@@ -21,7 +21,7 @@ blio_meta.pl - Set up & manage a Blio instance
 
 =head1 VERSION
 
-version 2.003
+version 2.006
 
 =head1 SYNOPSIS
 
@@ -50,11 +50,11 @@ L<blio.pl>, L<Blio>
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Thomas Klausner.
+This software is copyright (c) 2013 - 2022 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
