@@ -3,7 +3,7 @@ use 5.010;
 
 # ABSTRACT: domms blogging "engine"
 
-our $VERSION = 2.003;
+our $VERSION = 2.006;
 
 use Moose;
 use MooseX::Types::Path::Class;
@@ -12,6 +12,7 @@ use Path::Class::Iterator;
 use Template;
 use File::ShareDir qw(dist_dir);
 use DateTime;
+use MIME::Base64 qw(encode_base64url);
 
 use Blio::Node;
 
@@ -63,6 +64,7 @@ has 'converter' => (is=>'ro',isa=>'Maybe[Str]',default=>undef,required=>1);
 has 'thumbnail' => (is=>'ro',isa=>'Int',default=>300,required=>1);
 has 'tags' => (is=>'ro',isa=>'Bool',default=>0);
 has 'schedule' => (is=>'ro',isa=>'Bool',default=>0);
+has 'time_zone' => (is=>'ro',isa=>'Str', default=>'UTC');
 
 has 'force' => (is=>'ro',isa=>'Bool',default=>0);
 has 'quiet' => (is=>'ro',isa=>'Bool',default=>0);
@@ -120,6 +122,7 @@ sub _build_tagindex {
         title=>'Tags',
         date=>DateTime->now,
         content=>'',
+        list=>1,
     );
     $self->nodes_by_url->{'tags.html'}=$tagindex;
     return $tagindex;
@@ -140,7 +143,7 @@ sub collect {
     );
 
     my $schedule = $self->schedule;
-    my $now = DateTime->now;
+    my $now = DateTime->now(time_zone=>$self->time_zone);
 
     until ( $iterator->done ) {
         my $file = $iterator->next;
@@ -205,6 +208,16 @@ sub write {
 
 }
 
+sub absolute_url {
+    my ($self, $node) = @_;
+    return $self->site_url.'/'.$node->url;
+}
+
+sub absolute_base64_url {
+    my ($self, $node) = @_;
+    return encode_base64url($self->absolute_url($node));
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -220,7 +233,7 @@ Blio - domms blogging "engine"
 
 =head1 VERSION
 
-version 2.003
+version 2.006
 
 =head1 SYNOPSIS
 
@@ -313,11 +326,11 @@ TODO - there are more fields that need explanation.
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Thomas Klausner.
+This software is copyright (c) 2013 - 2022 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
