@@ -65,7 +65,7 @@ Blio::Image - An image node
 
 =head1 VERSION
 
-version 2.003
+version 2.006
 
 =head1 SYNOPSIS
 
@@ -115,11 +115,11 @@ Relative <Path::Class::File> object pointing to the thumbnailed image. This can
 
 =head1 AUTHOR
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Thomas Klausner.
+This software is copyright (c) 2013 - 2022 by Thomas Klausner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
